import type { ComposeOptions, Storage } from 'yeoman-generator';
import BaseGenerator from '../base/index.js';
import type { JHipsterGeneratorFeatures, JHipsterGeneratorOptions } from '../base/api.js';
import type { TaskTypes as DefaultTaskTypes } from '../../lib/types/application/tasks.js';
import type { ApplicationType } from '../../lib/types/application/application.js';
import type { Entity } from '../../lib/types/application/entity.js';
import type { GenericTaskGroup } from '../../lib/types/base/tasks.js';
import type { ApplicationConfiguration } from '../../lib/types/application/yo-rc.js';
import type SharedData from '../base/shared-data.js';
/**
 * This is the base class for a generator that generates entities.
 */
export default class BaseApplicationGenerator<E extends Entity = Entity, A extends ApplicationType<E> = ApplicationType<E>, TaskTypes extends DefaultTaskTypes<any, any> = DefaultTaskTypes<E, A>> extends BaseGenerator<TaskTypes> {
    static CONFIGURING_EACH_ENTITY: string;
    static LOADING_ENTITIES: string;
    static PREPARING_EACH_ENTITY: string;
    static PREPARING_EACH_ENTITY_FIELD: string;
    static PREPARING_EACH_ENTITY_RELATIONSHIP: string;
    static POST_PREPARING_EACH_ENTITY: string;
    static WRITING_ENTITIES: string;
    static POST_WRITING_ENTITIES: string;
    jhipsterConfig: ApplicationConfiguration & Record<string, any>;
    sharedData: SharedData<A>;
    constructor(args: string | string[], options: JHipsterGeneratorOptions, features: JHipsterGeneratorFeatures);
    dependsOnBootstrapApplication(options?: ComposeOptions | undefined): Promise<BaseApplicationGenerator<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>, {
        InitializingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        PromptingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        ConfiguringTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        ComposingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        LoadingTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplicationDefaults<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingTaskParam: import("../../lib/types/application/tasks.js").PreparingTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        ConfiguringEachEntityTaskParam: import("../../lib/types/application/tasks.js").ConfiguringEachEntityTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        LoadingEntitiesTaskParam: import("../../lib/types/application/tasks.js").LoadingEntitiesTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingEachEntityTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingEachEntityFieldTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityFieldTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingEachEntityRelationshipTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityRelationshipTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostPreparingEachEntityTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostPreparingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl & {
            source: import("../../lib/types/application/application.js").BaseApplicationSource;
        } & {
            application: ApplicationType<Entity<import("./index.js").Field, never>>;
        };
        DefaultTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithEntities<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        WritingTaskParam: import("../../lib/types/application/tasks.js").WritingTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        WritingEntitiesTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithEntities<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostWritingTaskParam: import("../../lib/types/application/tasks.js").PostWritingTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostWritingEntitiesTaskParam: import("../../lib/types/application/tasks.js").PostWritingEntitiesTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreConflictsTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        InstallTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostInstallTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        EndTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
    }>[]>;
    dependsOnBootstrapApplicationBase(options?: ComposeOptions | undefined): Promise<BaseApplicationGenerator<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>, {
        InitializingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        PromptingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        ConfiguringTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        ComposingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        LoadingTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplicationDefaults<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingTaskParam: import("../../lib/types/application/tasks.js").PreparingTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        ConfiguringEachEntityTaskParam: import("../../lib/types/application/tasks.js").ConfiguringEachEntityTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        LoadingEntitiesTaskParam: import("../../lib/types/application/tasks.js").LoadingEntitiesTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingEachEntityTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingEachEntityFieldTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityFieldTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingEachEntityRelationshipTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityRelationshipTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostPreparingEachEntityTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostPreparingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl & {
            source: import("../../lib/types/application/application.js").BaseApplicationSource;
        } & {
            application: ApplicationType<Entity<import("./index.js").Field, never>>;
        };
        DefaultTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithEntities<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        WritingTaskParam: import("../../lib/types/application/tasks.js").WritingTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        WritingEntitiesTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithEntities<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostWritingTaskParam: import("../../lib/types/application/tasks.js").PostWritingTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostWritingEntitiesTaskParam: import("../../lib/types/application/tasks.js").PostWritingEntitiesTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreConflictsTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        InstallTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostInstallTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        EndTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
    }>[]>;
    dependsOnBootstrapApplicationServer(options?: ComposeOptions | undefined): Promise<BaseApplicationGenerator<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>, {
        InitializingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        PromptingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        ConfiguringTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        ComposingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        LoadingTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplicationDefaults<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingTaskParam: import("../../lib/types/application/tasks.js").PreparingTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        ConfiguringEachEntityTaskParam: import("../../lib/types/application/tasks.js").ConfiguringEachEntityTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        LoadingEntitiesTaskParam: import("../../lib/types/application/tasks.js").LoadingEntitiesTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingEachEntityTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingEachEntityFieldTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityFieldTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingEachEntityRelationshipTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityRelationshipTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostPreparingEachEntityTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostPreparingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl & {
            source: import("../../lib/types/application/application.js").BaseApplicationSource;
        } & {
            application: ApplicationType<Entity<import("./index.js").Field, never>>;
        };
        DefaultTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithEntities<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        WritingTaskParam: import("../../lib/types/application/tasks.js").WritingTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        WritingEntitiesTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithEntities<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostWritingTaskParam: import("../../lib/types/application/tasks.js").PostWritingTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostWritingEntitiesTaskParam: import("../../lib/types/application/tasks.js").PostWritingEntitiesTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreConflictsTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        InstallTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostInstallTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        EndTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
    }>[]>;
    dependsOnBootstrapApplicationClient(options?: ComposeOptions | undefined): Promise<BaseApplicationGenerator<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>, {
        InitializingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        PromptingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        ConfiguringTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        ComposingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl;
        LoadingTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplicationDefaults<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingTaskParam: import("../../lib/types/application/tasks.js").PreparingTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        ConfiguringEachEntityTaskParam: import("../../lib/types/application/tasks.js").ConfiguringEachEntityTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        LoadingEntitiesTaskParam: import("../../lib/types/application/tasks.js").LoadingEntitiesTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingEachEntityTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingEachEntityFieldTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityFieldTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreparingEachEntityRelationshipTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityRelationshipTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostPreparingEachEntityTaskParam: import("../../lib/types/application/tasks.js").PreparingEachEntityTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostPreparingTaskParam: import("../../lib/types/base/tasks.js").TaskParamWithControl & {
            source: import("../../lib/types/application/application.js").BaseApplicationSource;
        } & {
            application: ApplicationType<Entity<import("./index.js").Field, never>>;
        };
        DefaultTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithEntities<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        WritingTaskParam: import("../../lib/types/application/tasks.js").WritingTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        WritingEntitiesTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithEntities<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostWritingTaskParam: import("../../lib/types/application/tasks.js").PostWritingTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostWritingEntitiesTaskParam: import("../../lib/types/application/tasks.js").PostWritingEntitiesTaskParam<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PreConflictsTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        InstallTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        PostInstallTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
        EndTaskParam: import("../../lib/types/application/tasks.js").TaskParamWithApplication<Entity<import("./index.js").Field, never>, ApplicationType<Entity<import("./index.js").Field, never>>>;
    }>[]>;
    /**
     * Get Entities configuration path
     * @returns
     */
    getEntitiesConfigPath(...args: any[]): string;
    /**
     * Get Entity configuration path
     * @param entityName Entity name
     * @returns
     */
    getEntityConfigPath(entityName: string): string;
    /**
     * Get all the generator configuration from the .yo-rc.json file
     * @param entityName - Name of the entity to load.
     * @param create - Create storage if doesn't exists.
     */
    getEntityConfig(entityName: string, create?: boolean): Storage | undefined;
    /**
     * get sorted list of entity names according to changelog date (i.e. the order in which they were added)
     */
    getExistingEntityNames(): string[];
    /**
     * get sorted list of entities according to changelog date (i.e. the order in which they were added)
     */
    getExistingEntities(): {
        name: string;
        definition: E;
    }[];
    /**
     * Priority API stub for blueprints.
     *
     * Configuring each entity should configure entities.
     */
    get configuringEachEntity(): {};
    get preparingEachEntity(): {};
    /**
     * Priority API stub for blueprints.
     */
    get preparingEachEntityField(): {};
    /**
     * Priority API stub for blueprints.
     */
    get preparingEachEntityRelationship(): {};
    /**
     * Priority API stub for blueprints.
     */
    get postPreparingEachEntity(): {};
    /**
     * Priority API stub for blueprints.
     */
    get writingEntities(): {};
    /**
     * Priority API stub for blueprints.
     */
    get postWritingEntities(): {};
    /**
     * Utility method to get typed objects for autocomplete.
     */
    asConfiguringEachEntityTaskGroup<const K extends string>(taskGroup: GenericTaskGroup<this, TaskTypes['ConfiguringEachEntityTaskParam'], K>): GenericTaskGroup<any, TaskTypes['ConfiguringEachEntityTaskParam'], K>;
    /**
     * Utility method to get typed objects for autocomplete.
     */
    asLoadingEntitiesTaskGroup<const K extends string>(taskGroup: GenericTaskGroup<this, TaskTypes['LoadingEntitiesTaskParam'], K>): GenericTaskGroup<any, TaskTypes['LoadingEntitiesTaskParam'], K>;
    /**
     * Utility method to get typed objects for autocomplete.
     */
    asPreparingEachEntityTaskGroup<const K extends string>(taskGroup: GenericTaskGroup<this, TaskTypes['PreparingEachEntityTaskParam'], K>): GenericTaskGroup<any, TaskTypes['PreparingEachEntityTaskParam'], K>;
    /**
     * Utility method to get typed objects for autocomplete.
     */
    asPreparingEachEntityFieldTaskGroup<const K extends string>(taskGroup: GenericTaskGroup<this, TaskTypes['PreparingEachEntityFieldTaskParam'], K>): GenericTaskGroup<any, TaskTypes['PreparingEachEntityFieldTaskParam'], K>;
    /**
     * Utility method to get typed objects for autocomplete.
     */
    asPreparingEachEntityRelationshipTaskGroup<const K extends string>(taskGroup: GenericTaskGroup<this, TaskTypes['PreparingEachEntityRelationshipTaskParam'], K>): GenericTaskGroup<any, TaskTypes['PreparingEachEntityRelationshipTaskParam'], K>;
    /**
     * Utility method to get typed objects for autocomplete.
     */
    asPostPreparingEachEntityTaskGroup<const K extends string>(taskGroup: GenericTaskGroup<this, TaskTypes['PostPreparingEachEntityTaskParam'], K>): GenericTaskGroup<any, TaskTypes['PostPreparingEachEntityTaskParam'], K>;
    /**
     * Utility method to get typed objects for autocomplete.
     */
    asWritingEntitiesTaskGroup<const K extends string>(taskGroup: GenericTaskGroup<this, TaskTypes['WritingEntitiesTaskParam'], K>): GenericTaskGroup<any, TaskTypes['WritingEntitiesTaskParam'], K>;
    /**
     * Utility method to get typed objects for autocomplete.
     */
    asPostWritingEntitiesTaskGroup<const K extends string>(taskGroup: GenericTaskGroup<this, TaskTypes['PostWritingEntitiesTaskParam'], K>): GenericTaskGroup<any, TaskTypes['PostWritingEntitiesTaskParam'], K>;
    /**
     * Reset entities fake data seed.
     * @param {string} seed
     */
    resetEntitiesFakeData(seed: any): void;
    getArgsForPriority(priorityName: any): any[];
    /**
     * @protected
     */
    protected getTaskFirstArgForPriority(priorityName: any): any;
    /**
     * @private
     * Get entities to configure.
     * This method doesn't filter entities. An filtered config can be changed at this priority.
     * @returns {string[]}
     */
    getEntitiesDataToConfigure(): {
        entityName: string;
        entityStorage: Storage | undefined;
        entityConfig: import("yeoman-generator").StorageRecord;
    }[];
    /**
     * @private
     * Get entities to load.
     * This method doesn't filter entities. An filtered config can be changed at this priority.
     * @returns {string[]}
     */
    getEntitiesDataToLoad(): {
        entityName: string;
        readonly entityStorage: Storage | undefined;
        readonly entityConfig: import("yeoman-generator").StorageRecord;
        entityBootstrap: any;
    }[];
    /**
     * @private
     * Get entities to prepare.
     * @returns {object[]}
     */
    getEntitiesDataToPrepare(): {
        entity: any;
        description: string;
        entityName: string;
    }[];
    /**
     * @private
     * Get entities and fields to prepare.
     * @returns {object[]}
     */
    getEntitiesFieldsDataToPrepare(): any[];
    /**
     * @private
     * Get entities and relationships to prepare.
     * @returns {object[]}
     */
    getEntitiesRelationshipsDataToPrepare(): any[];
    /**
     * @private
     * Get entities to post prepare.
     * @returns {object[]}
     */
    getEntitiesDataToPostPrepare(): {
        entity: any;
        description: string;
        entityName: string;
    }[];
    /**
     * @private
     * Get entities to write.
     * @returns {object[]}
     */
    getEntitiesDataForPriorities(): {
        entities: any[];
    };
    /**
     * @private
     * Get entities to write.
     * @returns {object[]}
     */
    getEntitiesDataToWrite(): {
        entities: any[];
    };
    /**
     * @private
     * Queue entity tasks.
     */
    queueEntityTasks(): void;
}
