import type { PrimaryKey } from '../../../lib/types/application/entity.js';
import type { FieldType } from '../../../lib/application/field-types.js';
/**
 * @private
 * Filter the relevant relationships fields on the model
 * @param {Array|Object} relationships - array of relationships
 * @returns {Array|Object} filtered relationships
 */
export declare const filterRelevantRelationships: (relationships: any) => any;
/**
 * @private
 * Generate Entity Client Imports
 *
 * @param {Array|Object} relationships - array of relationships
 * @param {string} dto - dto
 * @param {string} clientFramework the client framework, 'angular', 'vue' or 'react'.
 * @returns typeImports: Map
 */
export declare const generateEntityClientImports: (relationships: any, dto?: any, clientFramework?: any) => Map<any, any>;
/**
 * @private
 * Generate Entity Client Enum Imports
 *
 * @param {Array|Object} fields - array of the entity fields
 * @param {string} clientFramework the client framework, 'angular' or 'react'.
 * @returns typeImports: Map
 */
export declare const generateEntityClientEnumImports: (fields: any, clientFramework: any) => Map<any, any>;
/**
 * @private
 * Generate a primary key, according to the type
 *
 * @param {any} primaryKey - primary key definition
 * @param {number} index - the index of the primary key, currently it's possible to generate 2 values, index = 0 - first key (default), otherwise second key
 * @param {boolean} [wrapped=true] - wrapped values for required types.
 */
export declare const generateTestEntityId: (primaryKey: FieldType | PrimaryKey, index?: string | number, wrapped?: boolean) => any;
/**
 * @private
 * Generate a test entity, according to the type
 *
 * @param references
 * @param {number} [index] - index of the primary key sample, pass undefined for a random key.
 */
export declare const generateTestEntity: (references: any, index?: string) => {
    [k: string]: any;
};
/**
 * Generate a test entity, according to the references
 *
 * @param references
 * @param additionalFields
 * @return {String} test sample
 */
export declare const generateTypescriptTestEntity: (references: any, additionalFields?: {}) => string;
/**
 * Generate a test entity for the PK references (when the PK is a composite key)
 *
 * @param {any} primaryKey - primary key definition.
 * @param {number} [index] - index of the primary key sample, pass undefined for a random key.
 */
export declare const generateTestEntityPrimaryKey: (primaryKey: any, index: any) => string;
/**
 * @private
 * Get a parent folder path addition for entity
 * @param {string} clientRootFolder
 */
export declare const getEntityParentPathAddition: (clientRootFolder: any) => string;
