/**
 * Copyright 2013-2024 the original author or authors from the JHipster project.
 *
 * This file is part of the JHipster project, see https://www.jhipster.tech/
 * for more information.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import type { FieldType } from '../../../lib/application/field-types.js';
import type { PrimaryKey } from '../../../lib/types/application/entity.js';
/**
 * return the input if it's a type, otherwise returns the type attribute of the input
 * @param key
 * @returns {*}
 */
export declare const getEntryIfTypeOrTypeAttribute: (key: FieldType | PrimaryKey) => FieldType;
/**
 * @private
 * Find key type for Typescript
 *
 * @param {string | object} primaryKey - primary key definition
 * @returns {string} primary key type in Typescript
 */
declare const getTypescriptKeyType: (primaryKey: FieldType | PrimaryKey) => "string" | "number";
/**
 * @private
 * Find type for Typescript
 *
 * @param {string} fieldType - field type
 * @returns {string} field type in Typescript
 */
export declare const getTypescriptType: (fieldType: any) => any;
export default getTypescriptKeyType;
