import { upperFirstCamelCase } from '../utils/string.js';
export function loadConfig(configsDef, { application, config }) {
    if (configsDef) {
        for (const [name, def] of Object.entries(configsDef)) {
            let value = application[name];
            if (value === undefined || value === null) {
                let source = config;
                if (!source) {
                    if (def.scope === 'context') {
                        source = this.context;
                    }
                    else if (def.scope === 'blueprint') {
                        source = this.blueprintStorage.getAll();
                    }
                    else if (def.scope === 'storage' || def.scope === undefined) {
                        source = this.jhipsterConfigWithDefaults;
                    }
                }
                if (source) {
                    value = application[name] = source[name] ?? undefined;
                    if (value === undefined && def.default !== undefined) {
                        application[name] = typeof def.default === 'function' ? def.default.call(this, source) : def.default;
                    }
                }
            }
        }
    }
}
export const loadDerivedConfig = (configsDef, { application }) => {
    if (configsDef) {
        for (const [name, def] of Object.entries(configsDef)) {
            if ((def.scope === undefined || ['storage', 'blueprint', 'context'].includes(def.scope)) && def.choices) {
                const configVal = application[name];
                for (const choice of def.choices) {
                    const choiceVal = typeof choice === 'string' ? choice : choice.value;
                    const prop = `${name}${upperFirstCamelCase(choiceVal)}`;
                    application[prop] = application[prop] ?? [].concat(configVal).includes(choiceVal);
                }
                application[`${name}Any`] = application[`${name}Any`] ?? !application[`${name}No`];
            }
        }
    }
};
